@@ -11,12 +11,24 @@
         next
       xi <- x[, i]
       names(xi) <- NULL
-      ## Add:
+
+      ## SHD Add:
+      ## Handle characters
       if (!is.null(a$storage.mode) && a$storage.mode == "character"){
         xi <- a$flevels[xi]
         a$flevels <- NULL
       }
+      ## Handle times
+      if (!is.null(a$class)){
+        if (identical(a$class, c("POSIXt", "POSIXct"))){
+          if (a$storage.mode != sm)
+            storage.mode(xi) <- a$storage.mode
+          #a$storage.mode <- NULL
+          attributes(xi) <- a       
+        }          
+      }
       ## End !
+
       if (restoreAll) {
         if (a$storage.mode != sm)
           storage.mode(xi) <- a$storage.mode
@@ -44,16 +56,20 @@
         a$dim <- a$names <- a$dimnames <- NULL
         a$storage.mode <- storage.mode(y)
         ## Add:
-        if (class(y)=="character")
+        if (length(class(y))==1 && class(y)=="character")
           a$flevels <- levels(as.factor(y))
+        
         ## End!
         a
+      }
+    if (is.list(x)){
+      ##cat("calling 1\n")
+      sapply(x, g)
+    } else {
+      ##cat("calling 2\n")
+      g(x)
     }
-    if (is.list(x))
-        sapply(x, g)
-    else g(x)
-}
-
+  }
 
 
 
